<?php

namespace Drupal\imce_private\Plugin\CKEditorPlugin;

use Drupal\ckeditor\CKEditorPluginBase;
use Drupal\editor\Entity\Editor;

/**
 * Defines the "imceprivate" plugin.
 *
 * @CKEditorPlugin(
 *   id = "imceprivate",
 *   label = @Translation("ImcePrivate"),
 * )
 */
class ImcePrivate extends CKEditorPluginBase {
  use \Drupal\Core\StringTranslation\StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function getFile() {
    return drupal_get_path('module', 'imce_private') . '/js/plugins/ckeditor/imce.ckeditor.js';
  }

  /**
   * {@inheritdoc}
   */
  public function getButtons() {
    return [
      'ImceImagePrivate' => [
        'label' => $this->t('Insert private images using Imce File Manager'),
        'image' => $this->imageIcon(),
      ],
      'ImceLinkPrivate' => [
        'label' => $this->t('Insert private file links using Imce File Manager'),
        'image' => $this->linkIcon(),
      ],
      'ImceImagePublic' => [
        'label' => $this->t('Insert public images using Imce File Manager'),
        'image' => $this->imageIcon(),
      ],
      'ImceLinkPublic' => [
        'label' => $this->t('Insert public file links using Imce File Manager'),
        'image' => $this->linkIcon(),
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getConfig(Editor $editor) {
    return [
      'ImceImageIcon' => file_create_url($this->imageIcon()),
      'ImceLinkIcon' => file_create_url($this->linkIcon()),
    ];
  }

  /**
   * Returns image icon path. Uses the icon from drupalimage plugin.
   */
  public function imageIcon() {
    return drupal_get_path('module', 'imce') . '/js/plugins/ckeditor/icons/imceimage.png';
  }

  /**
   * Returns link icon path. Uses the icon from drupallink plugin.
   */
  public function linkIcon() {
    return drupal_get_path('module', 'imce') . '/js/plugins/ckeditor/icons/imcelink.png';
  }

}
